| Title: | Datasets for the 'canvasXpress' Package |
|---|---|
| Description: | Contains the prepared data that is needed for the 'shiny' application examples in the 'canvasXpress' package. This package also includes datasets used for automated 'testthat' tests. Scotto L, Narayan G, Nandula SV, Arias-Pulido H et al. (2008) <doi:10.1002/gcc.20577>. Davis S, Meltzer PS (2007) <doi:10.1093/bioinformatics/btm254>. |
| Authors: | Isaac Neuhaus [aut], Connie Brett [aut, cre], Ger Inberg [aut] |
| Maintainer: | Connie Brett <[email protected]> |
| License: | GPL-3 |
| Version: | 1.34.2 |
| Built: | 2026-05-16 05:29:40 UTC |
| Source: | https://github.com/neuhausi/canvasxpress.data |
This package contains data used and referenced in the canvasXpress R package
Get the file handle for given file in the package
get_data(file_name)get_data(file_name)
file_name |
the file name to retrieve (from the extdata folder) |
File handle to the given file or "" if it does not exist
sannot_file <- get_data("network_compact.tsv") # then read the file, for example: # data <- read.delim(sannot_file) # head(data)sannot_file <- get_data("network_compact.tsv") # then read the file, for example: # data <- read.delim(sannot_file) # head(data)
This example dataset is taken from the below referenced study. That study was aimed at identification of gene expression profiles in cervical cancer and the role of specific genes in cervical carcinogenesis.
This dataset was prepared for visualization by retrieving the gene expression values that follow the source data header information and moving the ID column to the rownames. This allows the storage and processing of the large numeric data as a matrix instead of a data frame for efficiency while retaining the ability to join it to the sample annotations and gene information.
GSE9750_expressionGSE9750_expression
A numeric matrix containing gene expression data
Scotto L, Narayan G, Nandula SV, Arias-Pulido H et al. Identification of copy number gain and overexpressed genes on chromosome arm 20q by an integrative genomic approach in cervical cancer: potential role in progression. Genes Chromosomes Cancer 2008 Sep; 47(9):755-65. PMID: 18506748
This example dataset is the gene information for genes present in the GSE9750 study referenced below. The data was retrieved from the GEOquery package referenced below.
This dataset was prepared for visualization by renaming the columns and subsetting to only the information necessary for visualization. The Symbol and Description fields were also cleaned and prepared.
GSE9750_gene_detailsGSE9750_gene_details
A dataframe containing gene metadata for the GSE9750 study
Davis, S. and Meltzer, P. S. GEOquery: a bridge between the Gene Expression Omnibus (GEO) and BioConductor. Bioinformatics, 2007, 14, 1846-1847
Scotto L, Narayan G, Nandula SV, Arias-Pulido H et al. Identification of copy number gain and overexpressed genes on chromosome arm 20q by an integrative genomic approach in cervical cancer: potential role in progression. Genes Chromosomes Cancer 2008 Sep; 47(9):755-65. PMID: 18506748
This example dataset is taken from the below referenced study. That study was aimed at identification of gene expression profiles in cervical cancer and the role of specific genes in cervical carcinogenesis.
This dataset was prepared for visualization by retrieving the sample characteristics from the original data file header. This was followed by reshaping and removal of special characters from the column headers. The data was further refined through dividing combined data and cleaning to create consistent values across samples before subsetting to extract the sample annotations of interest and binning the Age.
GSE9750_sample_annotGSE9750_sample_annot
A dataframe containing prepared sample annotation data
Scotto L, Narayan G, Nandula SV, Arias-Pulido H et al. Identification of copy number gain and overexpressed genes on chromosome arm 20q by an integrative genomic approach in cervical cancer: potential role in progression. Genes Chromosomes Cancer 2008 Sep; 47(9):755-65. PMID: 18506748